self.__BUILD_MANIFEST=function(s,a,c,t,e,p,d,i){return{__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":[s,a,"static/chunks/pages/index-9a325b5852eb5c88.js"],"/_error":["static/chunks/pages/_error-0a004b8b8498208d.js"],"/app/bridges/openon":[s,a,c,t,e,p,"static/chunks/pages/app/bridges/openon-5c7930440cd652da.js"],"/app/bridges/setup":[s,a,c,t,p,d,"static/chunks/203-eb2ad25fa22180ff.js","static/chunks/pages/app/bridges/setup-f11b322ef2aa8474.js"],"/app/data":[s,"static/chunks/29107295-fbcfe2172188e46f.js",a,c,"static/chunks/398-66eff0cad7a1b351.js",i,"static/chunks/pages/app/data-db0a6087bc8ed7ce.js"],"/app/settings":[s,a,c,t,e,d,"static/chunks/807-44078b0fbd3394af.js",i,"static/chunks/pages/app/settings-d3f08ac988abdbc7.js"],sortedPages:["/","/_app","/_error","/app/bridges/openon","/app/bridges/setup","/app/data","/app/settings"]}}("static/chunks/b2e984c5-af5b37b6e5a5729b.js","static/chunks/740-cae157bb35600788.js","static/chunks/524-b394bbba0432545d.js","static/chunks/301-4ad25b8c512087fd.js","static/chunks/545-9ebdbd2bcdefdfa4.js","static/chunks/669-a5e1f82fb9f952e9.js","static/chunks/257-3e10469570f1098e.js","static/chunks/471-c361b440c4bcf9c5.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();